%bcond_with docs

%global glib2_version 2.72.0
%global gnome_autoar_version 0.4.0
%global gtk4_version 4.7.2
%global libadwaita_version 1.2

Summary:        File manager for GNOME Provides the user with a simple way to navigate and manage files.
Name:           nautilus
Version:        44.2.1
%define major_ver %(echo %{version} | cut -d. -f1)
Release:        1%{?dist}
License:        GPLv3+
URL:            https://wiki.gnome.org/Apps/Files
Source0:        https://download.gnome.org/sources/%{name}/%{major_ver}/%{name}-%{version}.tar.xz

BuildRequires:  gcc meson
BuildRequires:  desktop-file-utils gettext /usr/bin/appstream-util
BuildRequires:  pkgconfig(gexiv2) pkgconfig(gnome-desktop-4) pkgconfig(gobject-introspection-1.0) pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) pkgconfig(gstreamer-tag-1.0) pkgconfig(libportal) pkgconfig(libportal-gtk4)
BuildRequires:  pkgconfig(libseccomp) pkgconfig(libselinux) pkgconfig(libxml-2.0) pkgconfig(tracker-sparql-3.0) pkgconfig(x11)
BuildRequires:  pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gnome-autoar-0) >= %{gnome_autoar_version}
BuildRequires:  pkgconfig(gtk4) >= %{gtk4_version}
BuildRequires:  pkgconfig(libadwaita-1) >= %{libadwaita_version}
%if 0%{with docs}
BuildRequires:  pkgconfig(gi-docgen)
%endif
Requires:       gsettings-desktop-schemas gvfs tracker3-miners
Requires:       glib2 >= %{glib2_version}
Requires:       gnome-autoar >= %{gnome_autoar_version}
Requires:       gtk4 >= %{gtk4_version}
Requires:       libadwaita >= %{libadwaita_version}
Requires:       %{name}-extensions = %{version}-%{release}
Provides:       bundled(libgd)

%description
Nautilus is the file manager and graphical shell for the GNOME desktop
that makes it easy to manage your files and the rest of your system.
It allows to browse directories on local and remote filesystems, preview
files and launch applications associated with them.
It is also responsible for handling the icons on the GNOME desktop.

%package extensions
Summary:        Nautilus extensions library
License:        LGPLv2+

%description extensions
This package provides the libraries used by nautilus extensions.

%package devel
Summary:        Support for developing nautilus extensions
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-extensions = %{version}-%{release}

%description devel
This package provides libraries and header files needed
for developing nautilus extensions.


%prep
%autosetup -p1 -n %{name}-%{version}


%build
%meson \
%if 0%{without docs}
  -Ddocs=false \
%else
  -Ddocs=true \
%endif
  -Dextensions=true \
  -Dintrospection=true \
  -Dselinux=true 

%meson_build


%install
%meson_install


%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/org.gnome.Nautilus.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop


%find_lang %{name}

%files  -f %{name}.lang
%license LICENSE
%doc NEWS README.md
%{_bindir}/*
%{_datadir}/applications/*
%{_datadir}/dbus-1/services/org.freedesktop.FileManager1.service
%{_datadir}/dbus-1/services/org.gnome.Nautilus.service
%{_datadir}/dbus-1/services/org.gnome.Nautilus.Tracker3.Miner.Extract.service
%{_datadir}/dbus-1/services/org.gnome.Nautilus.Tracker3.Miner.Files.service
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/glib-2.0/schemas/org.gnome.nautilus.gschema.xml
%{_datadir}/gnome-shell/search-providers/org.gnome.Nautilus.search-provider.ini
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Nautilus.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Nautilus-symbolic.svg
%{_datadir}/nautilus/
%{_datadir}/tracker3/domain-ontologies/org.gnome.Nautilus.domain.rule
%{_libdir}/nautilus/extensions-4/libnautilus-image-properties.so
%{_libdir}/nautilus/extensions-4/libtotem-properties-page.so
%{_metainfodir}/org.gnome.Nautilus.appdata.xml
%if 0%{with docs}
%{_mandir}/man1/nautilus.1*
%{_mandir}/man1/nautilus-autorun-software.1*
%endif

%files extensions
%license libnautilus-extension/LICENSE
%{_libdir}/libnautilus-extension.so.4*
%{_libdir}/girepository-1.0/Nautilus-4.0.typelib
%dir %{_libdir}/nautilus
%dir %{_libdir}/nautilus/extensions-4

%files devel
%{_includedir}/nautilus
%{_libdir}/pkgconfig/libnautilus-extension-4.pc
%{_libdir}/libnautilus-extension.so
%{_datadir}/gir-1.0/Nautilus-4.0.gir
%doc %{_datadir}/doc/nautilus/


%changelog
* Tue Sep 26 2023 rockerzhu <rockerzhu@tencent.com> - 44.2.1-1
- Upgrade to 44.2.1 to fix error with glib recent version.

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 17 2023 Xiaojie Chen <jackxjchen@tencent.com> - 43.0-3
- Rebuilt for gstreamer1-plugins-base 1.22.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 43.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 Miaojun Dong <zoedong@tencent.com> - 43.0-1
- initial build
